from tinkoff.invest import CandleInterval, Client
import pandas as pd
from ..settings import get_token, get_target
from ..utils import ticker_to_figi
from ..candle import Candle


def interval_transcription():
    transcription =  {
        '1m': CandleInterval.CANDLE_INTERVAL_1_MIN,
        '2m': CandleInterval.CANDLE_INTERVAL_2_MIN,
        '3m': CandleInterval.CANDLE_INTERVAL_3_MIN,
        '5m': CandleInterval.CANDLE_INTERVAL_5_MIN,
        '10m': CandleInterval.CANDLE_INTERVAL_10_MIN,
        '15m': CandleInterval.CANDLE_INTERVAL_15_MIN,
        '30m': CandleInterval.CANDLE_INTERVAL_30_MIN,
        '1h': CandleInterval.CANDLE_INTERVAL_HOUR,
        '2h': CandleInterval.CANDLE_INTERVAL_2_HOUR,
        '4h': CandleInterval.CANDLE_INTERVAL_4_HOUR,
        'day': CandleInterval.CANDLE_INTERVAL_DAY,
        'week': CandleInterval.CANDLE_INTERVAL_WEEK,
        'month': CandleInterval.CANDLE_INTERVAL_MONTH,
    }
    return transcription

def interval_to_t(interval):
    return interval_transcription()[interval]

def t_to_interval(interval):
    return {v: k for k, v in interval_transcription().items()}[interval]

def load_candles(ticker, interval, from_, to_):
    ans = pd.DataFrame()
    figi = ticker_to_figi(ticker)
    with Client(get_token(), target=get_target()) as client:
        for candle in client.get_all_candles(
            figi=figi,
            from_=from_,
            to=to_,
            interval=interval_to_t(interval),
        ):
            candle = Candle.from_t_candle(candle, interval)
            ans = pd.concat([ans, candle.to_df()])
    #print(ans)
    ans['datetime'] = pd.to_datetime(ans['datetime'])
    return ans.reset_index(drop=True).sort_values('datetime')

def load_single_price(ticker, date):
    with Client(get_token(), target=get_target()) as client:
        prices = load_candles(ticker, 'day', 
                              pd.to_datetime(date)-pd.DateOffset(days=30), # Тут если не торговались, то грузим раньше
                              pd.to_datetime(date)+pd.DateOffset(days=1))
        price = prices.tail(1)['close'].values[0]
        return price